<?php
/*
Plugin Name: Squid Analytics
Description: Simple, fast, and affordable marketing and product analytics for small businesses and startups.
Version: 1.0.7
Author: <a href="https://asksquid.ai">Squid, Inc.</a>
*/

// Always output the custom JS and squid.identify in the header if user is logged in
function squid_enqueue_custom_js() {
    $custom_js = get_option('squid_custom_js', '');
    if (!empty($custom_js)) {
        // Decode HTML entities in the custom JS before outputting
        echo html_entity_decode($custom_js, ENT_QUOTES, 'UTF-8');
    }
    
    $send_user_details = get_option('squid_send_user_details', 'off');
    if (is_user_logged_in() && $send_user_details === 'on') {
        $current_user = wp_get_current_user();
        $email = $current_user->user_email;

        echo '<script>$quid.identify({email : "' . esc_js($email) . '" });</script>';
    }
}
add_action('wp_head', 'squid_enqueue_custom_js');

// Send user data to Squid API only at the time of login
function squid_user_login($user_login, $user) {
    $send_user_details = get_option('squid_send_user_details', 'off');
    if ($send_user_details === 'on') {
        $email = $user->user_email;

        $custom_js = stripslashes(get_option('squid_custom_js', ''));
        preg_match('/\)\(\'(.+)\'/', $custom_js, $matches);
        $project_id = $matches[1] ?? '';

        $api_url = 'https://app.asksquid.ai/api/v1/track';
        $response = wp_remote_post($api_url, [
            'body' => json_encode([
                'project' => $project_id,
                'event' => 'identify',
                'label' => 'User Logged In',
                'context' => [
                    'traits' => [
                        'email' => $email,
                    ],
                ],
            ]),
            'headers' => [
                'Content-Type' => 'application/json'
            ],
        ]);

        if (is_wp_error($response)) {
            // Log the error or handle it appropriately here
        }
    }
}
add_action('wp_login', 'squid_user_login', 10, 2);


// Admin menu for the settings page
function squid_plugin_menu() {
    add_options_page('Squid Settings', 'Squid Analytics', 'manage_options', 'squid_plugin', 'squid_plugin_options');
}
add_action('admin_menu', 'squid_plugin_menu');

// Options/settings page in WP admin
function squid_plugin_options() {
    if (!current_user_can('manage_options')) {
        wp_die(esc_html__('You do not have sufficient permissions to access this page.'));
    }

    if (isset($_POST['squid_custom_js'])) {
        $allowed_html = [
            'script' => [
                'src' => [],
                'type' => [],
                'async' => [],
            ]
        ];
        update_option('squid_custom_js', wp_kses(stripslashes($_POST['squid_custom_js']), $allowed_html));
    }

    // Save the Checkbox state entered by the user
    if (isset($_POST['squid_send_user_details'])) {
        update_option('squid_send_user_details', sanitize_text_field($_POST['squid_send_user_details']));
    } else {
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            update_option('squid_send_user_details', 'off');
        }
    }

    echo '<div class="wrap">';
    echo '<h2>Squid Settings</h2>';
    echo '<form method="post" action="">';
    echo '<label for="squid_custom_js">Paste the Squid JS snippet here. You can find the snippet under your product settings within the Squid UI at <a href="https://app.asksquid.ai" target="_blank">https://app.asksquid.ai</a>.</label>';
    echo '<p>';
    echo '<textarea name="squid_custom_js" rows="15" cols="80" style="width:650px; height:165px; resize:none;">';
    echo esc_textarea(get_option('squid_custom_js', ''));
    echo '</textarea>';

    // Checkbox for sending user details
    echo '<p>';
    echo '<input type="checkbox" name="squid_send_user_details" id="squid_send_user_details" ' . checked(get_option('squid_send_user_details', 'off'), 'on', false) . '/>';
    echo '<label for="squid_send_user_details"> Send logged-in user data to Squid for identification. If this is unchecked, Squid will not capture the email address of the logged-in user.</label>';
    echo '</p>';

    echo '<p class="submit">';
    echo '<input type="submit" class="button-primary" value="Save Changes" />';
    echo '</p>';
    echo '</form>';
    echo '</div>';
}

// Function to add the settings link to the plugin action links
function squid_plugin_action_links($links) {
    $settings_link = '<a href="options-general.php?page=squid_plugin">Settings</a>';
    array_unshift($links, $settings_link); // Add to the start of the array
    return $links;
}

// Add the filter to show the settings link
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'squid_plugin_action_links');

// Check for plugin updates periodically
function check_for_plugin_updates() {
    if (false === ($update_data = get_transient('squid_plugin_update_check'))) {
        $response = wp_remote_get('https://plugins.asksquid.ai/wp_pi_manifest_106.txt');
        if (is_wp_error($response)) {
            return; // Early return on error, possibly add error logging here
        }

        $body = wp_remote_retrieve_body($response);
        $update_data = json_decode($body, true);

        // Store the update check data for 12 hours
        set_transient('squid_plugin_update_check', $update_data, 12 * HOUR_IN_SECONDS);
    }

    // If there's an update available and it's newer than the current version
    if (isset($update_data['new_version']) && version_compare($update_data['new_version'], '1.0.7', '>')) {
        // Store a transient indicating an update is available
        set_transient('squid_plugin_has_update', $update_data['new_version'], 12 * HOUR_IN_SECONDS);
    }
}
add_action('init', 'check_for_plugin_updates');

// Show an admin notice if there's an update available
function squid_plugin_update_admin_notice() {
    if ($new_version = get_transient('squid_plugin_has_update')) {
        $update_url = "YOUR_DOWNLOAD_LINK_HERE"; // You should replace this with the actual URL where users can download the update
        echo "<div class='notice notice-info is-dismissible'><p><strong>Squid Plugin Update:</strong> Version {$new_version} is now available! <a href='" . esc_url($update_url) . "'>Click here to download.</a></p></div>";
    }
}
add_action('admin_notices', 'squid_plugin_update_admin_notice');

?>
